{{ ansible_managed | comment }}

{% if ansible_distribution == 'Fedora' or (ansible_distribution == 'RedHat' and ansible_distribution_version|int >= 7) %}

KDUMP_COMMANDLINE_REMOVE="hugepages hugepagesz slub_debug quiet"

KDUMP_COMMANDLINE_APPEND="irqpoll nr_cpus=1 reset_devices cgroup_disable=memory mce=off numa=off udev.children-max=2 panic=10 rootflags=nofail acpi_no_memhotplug transparent_hugepage=never"

{% elif ansible_os_family == 'RedHat' and ansible_distribution_version|int < 7 %}

KDUMP_COMMANDLINE_APPEND="irqpoll nr_cpus=1 reset_devices cgroup_disable=memory mce=off acpi_no_memhotplug"

MKDUMPRD_ARGS=""

KDUMP_BOOTDIR="/boot"

{% endif %}

KDUMP_KERNELVER=""

KDUMP_COMMANDLINE=""

KEXEC_ARGS=""

KDUMP_IMG="vmlinuz"

KDUMP_IMG_EXT=""
